KeyInfo

Struct KeyInfo 

pub struct KeyInfo {
    pub kid: u8,
    pub key_type: KeyType,
    pub key_length: u8,
}
One key slot from the Key Information Template ('00E0').

v0.9k: the Extended-format key_usage/key_access placeholder fields were removed — the extended sub-template decode was never implemented, so they were structurally always None (an extended entry is still detected and reported via KeyTemplateFormat::Extended).

Fields

kid: u8key_type: KeyTypekey_length: u8